SWDEV-333188 - Port image tests to catch2 (#2793)

- Port image tests to catch2.
- Disable 3D filter test for gfx9a.
- Some other improvement
- Temporarily disable linear filter tests on Windows

Change-Id: Ieeddac9f8c50aa9b6b12ca9d8fd792a51973b8ca

[ROCm/hip commit: f3c171c984]
This commit is contained in:
ROCm CI Service Account
2022-07-19 19:26:56 +05:30
committato da GitHub
parent 551f9b4f76
commit 4e58d884c3
24 ha cambiato i file con 876 aggiunte e 124 eliminazioni
@@ -22,12 +22,16 @@ THE SOFTWARE.
texture<float, 2, hipReadModeElementType> tex;
__global__ void tex2DKernel(float* outputData, int width) {
#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
int x = blockIdx.x * blockDim.x + threadIdx.x;
int y = blockIdx.y * blockDim.y + threadIdx.y;
outputData[y * width + x] = tex2D(tex, x, y);
#endif
}
TEST_CASE("Unit_hipTextureRef2D_Check") {
CHECK_IMAGE_SUPPORT
constexpr int SIZE = 256;
constexpr unsigned int width = SIZE;
constexpr unsigned int height = SIZE;